@@ -24,6 +24,10 @@ static char *numbers[NBUF];
 	   3 if there is an unknown 
 	   4 if the buffer is too small */
 
+#ifdef YYDEBUG
+extern int yydebug;
+#endif
+
 int mpolin(MPOL *p)
 {
   MPOLINIT(&tempmon);
@@ -32,6 +36,9 @@ int mpolin(MPOL *p)
   status = 0;
   initall();
 
+#ifdef YYDEBUG
+  yydebug=1;
+#endif
   yyparse();
   mpolfree(&tempmon);
   if (status==0)
